##  Expanding Interfaces
Expanding Interfaces is a new feature with which you can understand the providing and consuming interfaces of an application directly within Free Draw and Data Flow.
  1. When the mouse pointer hovers over a shape that is linked to a fact sheet, semi-transparent arrows will appear on all sides of the shape.
  2. Hover over any of those arrows, depending on the direction you want to expand your diagram, to see the Interfaces of the respective fact sheet in a suggestion box.
  3. Click on the suggestion box to include the Interfaces in the diagram.


Arrows and not boxes then represent Interface fact sheets. You can still use Show dependencies and Drill-Down to get Interfaces as boxes in the regular fashion. The feature just adds a way to go from Application to Application directly.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274672ae7a441014aaa1bee09fb66316_LowRes.gif)
